"""Module for the classification of (biopsychological) data."""

from biopsykit.classification import analysis, model_selection, utils

__all__ = ["analysis", "model_selection", "utils"]
